@@ -1,6 +1,6 @@
 /*
     Scan and print all the PC/SC devices available
-    Copyright (C) 2001-2018  Ludovic Rousseau <ludovic.rousseau@free.fr>
+    Copyright (C) 2001-2022  Ludovic Rousseau <ludovic.rousseau@free.fr>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -151,8 +151,9 @@ static Boolean is_member(const char *  item, const char * list[])
 
 static void initialize_terminal(void)
 {
-	const char *color_terms[] = { "linux", "xterm", "xterm-color", "xterm-256color",
-		"Eterm", "rxvt", "rxvt-unicode", "cygwin", 0};
+	const char *color_terms[] = { "linux", "xterm", "xterm-color",
+		"xterm-256color", "Eterm", "rxvt", "rxvt-unicode", "cygwin",
+		"wsvt25", 0};
 	const char *no_ansi_cursor_terms[] = {"dumb", "emacs", 0};
 	const char *term = getenv("TERM");
 
@@ -290,13 +291,12 @@ static void initialize_signal_handlers(void)
 static void initialize_options(options_t *options, const char *pname)
 {
 	options->pname = pname;
-#ifdef WIN32
+#if defined(WIN32) || defined(__APPLE__)
 	options->analyse_atr = False;
 #else
 	options->analyse_atr = True;
 #endif
 	options->stress_card = False;
-	options->print_version = False;
 	options->maxtime = 0;
 	options->verbose = True;
 	options->only_list_readers = False;
@@ -310,6 +310,13 @@ static void initialize_options(options_t *options, const char *pname)
 #define OPTIONS OPTIONS_BASE "n"
 #endif
 
+static void print_version(void)
+{
+	printf("PC/SC device scanner\n");
+	printf("V %s (c) 2001-2022, Ludovic Rousseau <ludovic.rousseau@free.fr>\n",
+			PACKAGE_VERSION);
+}
+
 static int parse_options(int argc, char *argv[], options_t *options)
 {
 	const char *pname = argv[0];
@@ -324,7 +331,8 @@ static int parse_options(int argc, char *argv[], options_t *options)
 				break;
 
 			case 'V':
-				options->print_version = True;
+				print_version();
+				exit(EX_OK);
 				break;
 
 			case 'v':
@@ -472,13 +480,6 @@ static void print_readers(const char **readers, int nbReaders)
 	}
 }
 
-static void print_version(void)
-{
-	printf("PC/SC device scanner\n");
-	printf("V %s (c) 2001-2018, Ludovic Rousseau <ludovic.rousseau@free.fr>\n",
-			PACKAGE_VERSION);
-}
-
 int main(int argc, char *argv[])
 {
 	int current_reader;
@@ -505,10 +506,9 @@ int main(int argc, char *argv[])
 	{
 		exit(EX_USAGE);
 	}
-	if (Options.print_version)
+	if (Options.verbose)
 	{
 		print_version();
-		exit(EX_OK);
 	}
 
 #ifdef WIN32
@@ -608,6 +608,7 @@ get_readers:
 		if (Options.only_list_cards || Options.only_list_readers)
 		{
 			printf("No reader found.\n");
+			(void)SCardReleaseContext(hContext);
 			return EX_OK;
 		}
 
@@ -682,6 +683,7 @@ get_readers:
 		print_readers(readers, nbReaders);
 	if (Options.only_list_readers)
 	{
+		(void)SCardReleaseContext(hContext);
 		exit(EX_OK);
 	}
 
@@ -690,6 +692,7 @@ get_readers:
 	if (NULL == rgReaderStates_t)
 	{
 		fprintf(stderr, "%s: Not enough memory for readers states\n", Options.pname);
+		(void)SCardReleaseContext(hContext);
 		exit(EX_OSERR);
 	}
 
